kssanalysis
===================


kssanalysis is the library used to check the context of the word i.e if the word is positive or negative or neutral.

----------


Documents
-------------

let's take a look at this,

> **Syntax:**

word('string')
It will check that the input string is positive or negative.
It should be a word only **no spaces** and **.** are allowed.

>**Version:**

It is 1st version of kssanalysis, it only checks the word but future versions may include sentence and paragraph as team is currently working on it.